/**
 * Welcome to @reach/tabs!
 *
 * An accessible tabs component.
 *
 * The `Tab` and `TabPanel` elements are associated by their order in the tree.
 * None of the components are empty wrappers, each is associated with a real DOM
 * element in the document, giving you maximum control over styling and composition.
 *
 * You can render any other elements you want inside of `Tabs`, but `TabList`
 * should only render `Tab` elements, and `TabPanels` should only render
 * `TabPanel` elements.
 *
 * @see Docs     https://reacttraining.com/reach-ui/tabs
 * @see Source   https://github.com/reach/reach-ui/tree/master/packages/tabs
 * @see WAI-ARIA https://www.w3.org/TR/wai-aria-practices-1.2/#tabpanel
 */
import React from "react";
export declare enum TabsKeyboardActivation {
    Auto = "auto",
    Manual = "manual"
}
export declare enum TabsOrientation {
    Horizontal = "horizontal",
    Vertical = "vertical"
}
/**
 * Tabs
 *
 * The parent component of the tab interface.
 *
 * @see Docs https://reacttraining.com/reach-ui/tabs#tabs
 */
export declare const Tabs: import("@reach/utils").ComponentWithAs<"div", TabsProps>;
/**
 * @see Docs https://reacttraining.com/reach-ui/tabs#tabs-props
 */
export declare type TabsProps = {
    /**
     * Tabs expects `<TabList>` and `<TabPanels>` as children. The order doesn't
     * matter, you can have tabs on the top or the bottom. In fact, you could have
     * tabs on both the bottom and the top at the same time. You can have random
     * elements inside as well.
     *
     * You can also pass a render function to access data relevant to nested
     * components.
     *
     * @see Docs https://reacttraining.com/reach-ui/tabs#tabs-children
     */
    children: React.ReactNode | ((props: TabsContextValue) => React.ReactNode);
    /**
     * Like form inputs, a tab's state can be controlled by the owner. Make sure
     * to include an `onChange` as well, or else the tabs will not be interactive.
     *
     * @see Docs https://reacttraining.com/reach-ui/tabs#tabs-index
     */
    index?: number;
    /**
     * Describes the activation mode when navigating a tablist with a keyboard.
     * When set to `"auto"`, a tab panel is activated automatically when a tab is
     * highlighted using arrow keys. When set to `"manual"`, the user must
     * activate the tab panel with either the `Spacebar` or `Enter` keys. Defaults
     * to `"auto"`.
     *
     * @see Docs https://reacttraining.com/reach-ui/tabs#tabs-keyboardactivation
     */
    keyboardActivation?: TabsKeyboardActivation;
    /**
     * @see Docs https://reacttraining.com/reach-ui/tabs#tabs-readonly
     */
    readOnly?: boolean;
    /**
     * Starts the tabs at a specific index.
     *
     * @see Docs https://reacttraining.com/reach-ui/tabs#tabs-defaultindex
     */
    defaultIndex?: number;
    /**
     * Allows you to switch the orientation of the tabs relative to their tab
     * panels. Defaults to `"horizontal-start"`.
     *
     * `horizontal-` and `vertical-` orientations will change how the arrow keys
     * navigate between tabs. Arrow key navigation should logically follow the
     * order in which tabs appear on the screen. For screen reader users, the
     * `aria-orientation` attribute provides the appropriate context to direct
     * which keys should navigate to the next tab (this is provided
     * automatically).
     *
     * `-start` and `-end` props should be determined by the DOM order of rendered
     * components. If the `TabList` component appears before `TabPanels`, the
     * `horizontal-start` or `vertical-start` should be used. When the `TabList`
     * component appears after `TabPanels`, use `horizontal-end` or
     * `vertical-end`. For vertical tabs, this will change whether or not
     * `ArrowLeft` or `ArrowRight` moves the user into the active panel.
     *
     * If you're familiar with the relatively new specs for CSS logical
     * properties, you'll know why we opt to use `start` and `end` rather than
     * `left`, `right`, `top` or `bottom`. The `Tabs` component supports writing
     * modes other than left-to-right, and `Tabs` will adapt keyboard controls to
     * the match user's writing mode and the given orientation.
     *
     * @see Docs https://reacttraining.com/reach-ui/tabs#tabs-orientation
     * @see MDN  https://developer.mozilla.org/en-US/docs/Web/CSS/CSS_Logical_Properties
     */
    orientation?: TabsOrientation;
    /**
     * Calls back with the tab index whenever the user changes tabs, allowing your
     * app to synchronize with it.
     *
     * @see Docs https://reacttraining.com/reach-ui/tabs#tabs-onchange
     */
    onChange?: (index: number) => void;
};
declare const TabList: React.NamedExoticComponent<import("@reach/utils").PropsWithAs<"div", TabListProps>>;
/**
 * @see Docs https://reacttraining.com/reach-ui/tabs#tablist-props
 */
export declare type TabListProps = {
    /**
     * `TabList` expects multiple `Tab` elements as children.
     *
     * `TabPanels` expects multiple `TabPanel` elements as children.
     *
     * @see Docs https://reacttraining.com/reach-ui/tabs#tablist-children
     */
    children?: React.ReactNode;
};
export { TabList };
/**
 * Tab
 *
 * The interactive element that changes the selected panel.
 *
 * @see Docs https://reacttraining.com/reach-ui/tabs#tab
 */
export declare const Tab: import("@reach/utils").ComponentWithAs<"button", TabProps & {
    isSelected?: boolean | undefined;
}>;
/**
 * @see Docs https://reacttraining.com/reach-ui/tabs#tab-props
 */
export declare type TabProps = {
    /**
     * `Tab` can receive any type of children.
     *
     * @see Docs https://reacttraining.com/reach-ui/tabs#tab-children
     */
    children?: React.ReactNode;
    /**
     * Disables a tab when true. Clicking will not work and keyboard navigation
     * will skip over it.
     *
     * @see Docs https://reacttraining.com/reach-ui/tabs#tab-disabled
     */
    disabled?: boolean;
};
declare const TabPanels: React.NamedExoticComponent<import("@reach/utils").PropsWithAs<"div", TabListProps>>;
/**
 * @see Docs https://reacttraining.com/reach-ui/tabs#tabpanels-props
 */
export declare type TabPanelsProps = TabListProps & {};
export { TabPanels };
/**
 * TabPanel
 *
 * The panel that displays when it's corresponding tab is active.
 *
 * @see Docs https://reacttraining.com/reach-ui/tabs#tabpanel
 */
export declare const TabPanel: import("@reach/utils").ComponentWithAs<"div", TabPanelProps>;
/**
 * @see Docs https://reacttraining.com/reach-ui/tabs#tabpanel-props
 */
export declare type TabPanelProps = {
    /**
     * `TabPanel` can receive any type of children.
     *
     * @see Docs https://reacttraining.com/reach-ui/tabs#tabpanel-children
     */
    children?: React.ReactNode;
};
/**
 * A hook that exposes data for a given `Tabs` component to its descendants.
 *
 * @see Docs https://reacttraining.com/reach-ui/tabs#usetabscontext
 */
export declare function useTabsContext(): TabsContextValue;
export declare type TabsContextValue = {
    focusedIndex: number;
    id: string;
    selectedIndex: number;
};
